View source: R/bargain_calibrate.R
| bargain_calibrate | R Documentation |
Nash bargaining calibration
bargain_calibrate(
param,
own,
price,
shares,
cost,
weight = NA,
lambda,
includeMUI = TRUE
)
param |
Price coefficient alpha and mean values delta, parameters to calibrate |
own |
Ownership matrix |
price |
Price |
shares |
Observed market shares |
cost |
Marginal costs for each product |
weight |
Weighting vector of length 2*J |
lambda |
Bargaining power of the buyer |
includeMUI |
logical; whether to include marginal utility of income in buyer's payoff, thereby translating dollars to utility. Default is True, interpreted as buyer maximizing utility. Setting equal to False would have interpretation that buyer maximizes profts. |
This function calculate the first-order conditions from a Bertrand price-setting model of competition
The first-order conditions
alpha <- -0.9
delta <- c(.81,.93,.82)
c_j <- c(.05,.31,.30)
own_pre = diag(3)
p0 <- c_j*1.1
share1 <- (exp(delta + alpha*p0))/(1+sum(exp(delta + alpha*p0)))
wt_vector <- c(1,1,1,1000,1000,1000)
bargain_calibrate(param = c(alpha,delta),own = own_pre,price = p0,
shares = share1,cost = c_j, weight = wt_vector,
lambda = 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.