bargain_foc: Nash bargaining first-order conditions

View source: R/bargain_foc.R

bargain_focR Documentation

Nash bargaining first-order conditions

Description

Nash bargaining first-order conditions

Usage

bargain_foc(price, own, alpha, delta, cost, lambda, includeMUI = TRUE)

Arguments

price

Price

own

Ownership matrix

alpha

Price coefficient

delta

Mean values

cost

Marginal costs for each product

lambda

Bargaining power of the buyer

includeMUI

logical; whether to include marginal utility of income in buyer's payoff, thereby translating dollars to utility. Default is True, interpreted as buyer maximizing utility. Setting equal to False would have interpretation that buyer maximizes profits.

Details

This function calculate the first-order conditions from a Bertrand price-setting model of competition

Value

The first-order conditions

Examples

alpha  <- -0.9
delta <- c(.81,.93,.82)
c_j <- c(.05,.31,.30)
own_pre = diag(3)
p0 <- c_j*1.1

bertrand_foc(price = p0,
own = own_pre, alpha= alpha,
delta = delta, cost = c_j)


mergersim documentation built on July 21, 2026, 5:09 p.m.