bargain_vert_seq_calibrate: Calibrate costs for Nash bargain in vertical model with...

View source: R/bargain_vert_seq_calibrate.R

bargain_vert_seq_calibrateR Documentation

Calibrate costs for Nash bargain in vertical model with sequential timing

Description

Calibrate costs for Nash bargain in vertical model with sequential timing

Usage

bargain_vert_seq_calibrate(
  c_w_val,
  price_w,
  own_down,
  own_up,
  alpha,
  delta,
  lambda,
  cost_r,
  price_r,
  sigma,
  setTol = 0.01,
  setMaxIter = 500,
  showAll = FALSE,
  symmetricCosts = FALSE
)

Arguments

c_w_val

Wholesale/upstream costs

price_w

Upstream or wholesale prices

own_down

Ownership matrix for downstream firms

own_up

Ownership matrix for upstream firms

alpha

Price coefficient

delta

Mean values

lambda

Bargaining power of the buyer/retailer

cost_r

Marginal costs for downstream firm for each product

price_r

Retail prices

sigma

Contract type; value between 0 and 1 where 0 is linear price, 1 is two-part tariff

setTol

tolerance for convergence

setMaxIter

Maximum iterations for convergence loop

showAll

logical; if true, returns gains for trade for every product

symmetricCosts

Constrain costs to be symmetric

Details

This function can be used to calibrate the costs in a Nash bargain which is the upstream market of a vertical supply chain. Assumes logit demand.

Value

The value of objective function

Examples

bargain_vert_seq_calibrate(c_w_val = rep(.2, times = 6),
price_w = c(1.6, 1.6, 1.6, 1.6, 1.6, 1.6),
own_down = paste0("R",rep(c(1,2,3),each=2)),
own_up = paste0("W",rep(c(1,2),3)),
alpha = -0.9, delta = c(0.2, 0.3, 0.9, 1.0, 0.8, 0.9),
lambda = 0.5, cost_r = rep(.1, times = 6),
price_r = c(2.9, 2.9, 3.0, 3.0, 3.0, 3.0),
sigma = 0, setTol = 1.5)


mergersim documentation built on July 21, 2026, 5:09 p.m.