bargain_vert_sim_calibrate: Calibrate lambda for Nash bargain in vertical model with...

View source: R/bargain_vert_sim_calibrate.R

bargain_vert_sim_calibrateR Documentation

Calibrate lambda for Nash bargain in vertical model with simultaneous timing

Description

Calibrate lambda for Nash bargain in vertical model with simultaneous timing

Usage

bargain_vert_sim_calibrate(
  lambda,
  price_w,
  own_down,
  own_up,
  alpha,
  delta,
  cost_w,
  cost_r,
  price_r
)

Arguments

lambda

Bargaining power of the buyer/retailer

price_w

Upstream or wholesale prices

own_down

Ownership matrix for downstream firms

own_up

Ownership matrix for upstream firms

alpha

Price coefficient

delta

Mean values

cost_w

Marginal costs for upstream firm for each product

cost_r

Marginal costs for downstream firm for each product

price_r

Retail prices

Details

This function can be used to calibrate the bargaining parameter in a Nash bargain which is the upstream market of a vertical supply chain. Assumes logit demand.

Value

The value of objective function

Examples

bargain_vert_sim_calibrate(lambda = 0.4,
price_w = c(1.6, 1.6, 1.6, 1.6, 1.6, 1.6),
own_down = paste0("R",rep(c(1,2,3),each=2)),
own_up = paste0("W",rep(c(1,2),3)),
alpha = -0.9,
delta = c(0.2, 0.3, 0.9, 1.0, 0.8, 0.9),
cost_w = rep(.2, times = 6),
cost_r = rep(.1, times = 6),
price_r = c(2.9, 2.9, 3.0, 3.0, 3.0, 3.0))


mergersim documentation built on July 21, 2026, 5:09 p.m.