bargain_vert_sim_calibrate_gnl: Calibrate upstream Nash bargain in vertical model with...

View source: R/bargain_vert_sim_calibrate_gnl.R

bargain_vert_sim_calibrate_gnlR Documentation

Calibrate upstream Nash bargain in vertical model with simultaneous timing

Description

Calibrate upstream Nash bargain in vertical model with simultaneous timing

Usage

bargain_vert_sim_calibrate_gnl(
  param,
  lambda = NA,
  cost_w = NA,
  own_down,
  own_up,
  alpha,
  delta,
  cost_r,
  price_r,
  price_w,
  nest_allocation = NA,
  mu = NA,
  sumFOC = FALSE
)

Arguments

param

vector of parameters to calibrate, will be either bargaining parameter or demand parameters, depending on what other information is supplied

lambda

Bargaining power of the buyer/retailer

cost_w

Marginal costs for upstream firm for each product

own_down

Ownership matrix for downstream firms

own_up

Ownership matrix for upstream firms

alpha

Price coefficient

delta

Mean values

cost_r

Marginal costs for downstream firm for each product

price_r

Retail prices

price_w

Upstream or wholesale prices

nest_allocation

For generalized nested logit demand, a J-by-K matrix where each element (j,k) designates the membership of good j in nest k. Rows should sum to 1.

mu

Nesting parameters for each nest

sumFOC

logical; whether to return the sum of squares of the first-order conditions. Defaults to FALSE, in which case it returns each product first-order condition as a vector.

Details

This function can be used to calibrate the bargaining parameter in a Nash bargain which is the upstream market of a vertical supply chain. Assumes logit demand.

Value

The value of objective function

Examples

bargain_vert_sim_calibrate_gnl(param = 0.4, lambda=NA,
cost_w = rep(.2, times = 6),
own_down = paste0("R",rep(c(1,2,3),each=2)),
own_up = paste0("W",rep(c(1,2),3)),
alpha = -0.9,
delta = c(0.2, 0.3, 0.9, 1.0, 0.8, 0.9),
cost_r = rep(.1, times = 6),
price_r = c(2.9, 2.9, 3.0, 3.0, 3.0, 3.0),
price_w = c(1.6, 1.6, 1.6, 1.6, 1.6, 1.6),
nest_allocation=NA, mu=NA, sumFOC = TRUE)


mergersim documentation built on July 21, 2026, 5:09 p.m.