bertrand_foc_vert: Downstream Bertrand first-order conditions

View source: R/bertrand_foc_vert.R

bertrand_foc_vertR Documentation

Downstream Bertrand first-order conditions

Description

Downstream Bertrand first-order conditions

Usage

bertrand_foc_vert(
  price_r,
  own_down,
  own_up,
  alpha,
  delta,
  cost_r,
  price_w,
  cost_w,
  sumFOC = FALSE
)

Arguments

price_r

Downstream or retail prices

own_down

Ownership matrix for downstream firms

own_up

Ownership matrix for upstream firms

alpha

Price coefficient

delta

Mean values

cost_r

Marginal costs for downstream firm for each product

price_w

Upstream or wholesale prices, treated as costs by downstream firms

cost_w

Marginal costs for upstream firm for each product

sumFOC

logical; whether to return the sum of squares of the first-order conditions. Defaults to FALSE, in which case it returns each product first-order condition as a vector.

Details

This function calculates the first-order conditions from a Bertrand price-setting model of competition as the downstream market of a vertical supply chain. Assumes logit demand.

Value

The first-order conditions


mergersim documentation built on July 21, 2026, 5:09 p.m.