match_share: Market share calculations

View source: R/match_share.R

match_shareR Documentation

Market share calculations

Description

Calculates choice probabilities based on logit or generalized nested logit demand parameters

Usage

match_share(price, delta, alpha, nest_allocation = NA, mu = NA, shares_obs)

Arguments

price

Price

delta

Mean values

alpha

Price coefficient

nest_allocation

For generalized nested logit demand, a J-by-K matrix where each element (j,k) designates the membership of good j in nest k. Rows should sum to 1.

mu

Nesting parameters for each nest

shares_obs

Observed market shares

Details

This function calculates the difference between model predicted choice probabilities and observed market shares.

Value

Returns vector of difference between predicted shares and observed shares

Examples

match_share(price=c(2.1,2.4,2.1), delta=c(.81,.93,.82), alpha=-0.9,
shares_obs = c(.2, .2, .2))


mergersim documentation built on July 21, 2026, 5:09 p.m.