ssbargain_calibrate: Second score bargaining first-order conditions

View source: R/ssbargain_calibrate.R

ssbargain_calibrateR Documentation

Second score bargaining first-order conditions

Description

Second score bargaining first-order conditions

Usage

ssbargain_calibrate(
  param,
  own,
  price,
  shares,
  cost,
  weight = NA,
  lambda,
  includeMUI = TRUE
)

Arguments

param

Price coefficient alpha and mean values delta, parameters to calibrate

own

Ownership matrix

price

Price

shares

Observed market shares

cost

Marginal costs for each product

weight

Weighting vector of length 2*J

lambda

Bargaining power of the buyer

includeMUI

logical; whether to include marginal utility of income in buyer's payoff, thereby translating dollars to utility. Default is True, interpreted as buyer maximizing utility. Setting equal to False would have interpretation that buyer maximizes profits.

Details

This function calculate the first-order conditions from a bargaining model that nests the second score auction.

Value

The first-order conditions

Examples

alpha  <- -0.9
delta <- c(.81,.93,.82)
own_pre = diag(3)
p0 <- c(.05, .34, .33)
c_j <- c(.05,.31,.30)
wt_vector <- c(1,1,1,1000,1000,1000)
share1 <- c( 0.31, 0.27, 0.25)

ssbargain_calibrate(param = c(alpha,delta),own = own_pre,price = p0,
                    shares = share1, cost = c_j, weight = wt_vector,
                    lambda = 0.5)


mergersim documentation built on July 21, 2026, 5:09 p.m.