| bargain_foc | R Documentation |
Nash bargaining first-order conditions
bargain_foc(price, own, alpha, delta, cost, lambda, includeMUI = TRUE)
price |
Price |
own |
Ownership matrix |
alpha |
Price coefficient |
delta |
Mean values |
cost |
Marginal costs for each product |
lambda |
Bargaining power of the buyer |
includeMUI |
logical; whether to include marginal utility of income in buyer's payoff, thereby translating dollars to utility. Default is True, interpreted as buyer maximizing utility. Setting equal to False would have interpretation that buyer maximizes profits. |
This function calculate the first-order conditions from a Bertrand price-setting model of competition
The first-order conditions
alpha <- -0.9
delta <- c(.81,.93,.82)
c_j <- c(.05,.31,.30)
own_pre = diag(3)
p0 <- c_j*1.1
bertrand_foc(price = p0,
own = own_pre, alpha= alpha,
delta = delta, cost = c_j)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.