| match_share | R Documentation |
Calculates choice probabilities based on logit or generalized nested logit demand parameters
match_share(price, delta, alpha, nest_allocation = NA, mu = NA, shares_obs)
price |
Price |
delta |
Mean values |
alpha |
Price coefficient |
nest_allocation |
For generalized nested logit demand, a J-by-K matrix where each element (j,k) designates the membership of good j in nest k. Rows should sum to 1. |
mu |
Nesting parameters for each nest |
shares_obs |
Observed market shares |
This function calculates the difference between model predicted choice probabilities and observed market shares.
Returns vector of difference between predicted shares and observed shares
match_share(price=c(2.1,2.4,2.1), delta=c(.81,.93,.82), alpha=-0.9,
shares_obs = c(.2, .2, .2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.