View source: R/ssa_calibrate.R
| ssa_calibrate | R Documentation |
Second score auction calibration
ssa_calibrate(param, own, price, share, cost, weight = NA)
param |
The price coefficient alpha to be calibrated |
own |
Ownership matrix |
price |
Price |
share |
Share |
cost |
Marginal costs for each product |
weight |
Weighting vector of length equal to number of observed costs |
This function calculate the first-order conditions from a second score auction model of competition
The first-order conditions
own_pre = diag(3)
p0 <- c(.05, .34, .33)
share1 <- c( 0.31, 0.27, 0.25)
c_j <- c(.05,.31,.30)
wt_vector <- c(1,1,1)
ssa_calibrate(param = -1,own = own_pre,price=p0,share=share1,cost=c_j,
weight = wt_vector)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.